@@ -1,3 +1,4 @@
+import os
 DATABASES = {
     'default': {
         'ENGINE': 'django.db.backends.sqlite3',
@@ -6,4 +7,6 @@ DATABASES = {
     }
 }
 
-INSTALLED_APPS = ['testdata']
\ No newline at end of file
+INSTALLED_APPS = ['testdata']
+
+TEMPLATE_DIRS = [os.path.join(os.path.dirname(__file__), 'templates')]
\ No newline at end of file
